.. _functions:

Mathematical Functions
**********************

.. module:: diofant.functions

All functions support the methods documented below, inherited from
:py:class:`diofant.core.function.Function`.

.. autoclass:: diofant.core.function.Function
   :noindex:
   :members:

.. _functions-contents:

Contents
========

.. toctree::
   :maxdepth: 2

   elementary.rst
   combinatorial.rst
   special.rst
